@@ -83,7 +83,7 @@ class pts_client
 				if(count($module_r) == 2)
 				{
 					// TODO: end up hooking this into pts_module::read_variable() rather than using the real env
-					pts_client::set_environmental_variable($module_r[0], $module_r[1]);
+					pts_client::set_environment_variable($module_r[0], $module_r[1]);
 				}
 				else
 				{
@@ -313,13 +313,14 @@ class pts_client
 
 				// Generate logs from system commands to backup
 				$system_log_commands = array(
-					'lspci -vvnn',
+					'lspci -mmkvvvnn',
 					'lscpu',
 					'cc -v',
 					'lsusb',
 					'lsmod',
 					'sensors',
 					'dmesg',
+					'vdpauinfo',
 					'cpufreq-info',
 					'glxinfo',
 					'clinfo',
@@ -908,7 +909,7 @@ class pts_client
 		$raw_xsl = file_get_contents(PTS_RESULTS_VIEWER_PATH . 'pts-results-viewer.xsl');
 
 		// System Tables
-		$conversions = array('systems', 'radar', 'overview', 'visualize');
+		$conversions = array('systems', 'detailed_component', 'radar', 'overview', 'visualize');
 		foreach($conversions as $convert)
 		{
 			$graph_string = pts_svg_dom::html_embed_code('result-graphs/' . $convert . '.BILDE_EXTENSION', 'SVG', array('width' => 'auto', 'height' => 'auto'), true);
@@ -947,7 +948,7 @@ class pts_client
 			$chart->renderChart($save_to_dir . '/result-graphs/overview.BILDE_EXTENSION');
 
 			$intent = -1;
-			if($result_file->get_system_count() == 1 || ($intent = pts_result_file_analyzer::analyze_result_file_intent($result_file, $intent, true)))
+			if(($intent = pts_result_file_analyzer::analyze_result_file_intent($result_file, $intent, true)) || $result_file->get_system_count() == 1)
 			{
 				$chart = new pts_ResultFileCompactSystemsTable($result_file, $intent);
 			}
@@ -957,6 +958,16 @@ class pts_client
 			}
 			$chart->renderChart($save_to_dir . '/result-graphs/systems.BILDE_EXTENSION');
 			unset($chart);
+
+			if($intent && is_dir($save_to_dir . '/system-logs/'))
+			{
+				$chart = new pts_DetailedSystemComponentTable($result_file, $save_to_dir . '/system-logs/', $intent);
+
+				if($chart)
+				{
+					$chart->renderChart($save_to_dir . '/result-graphs/detailed_component.BILDE_EXTENSION');
+				}
+			}
 		}
 
 		foreach($result_file->get_result_objects() as $key => $result_object)
@@ -1028,6 +1039,13 @@ class pts_client
 				}
 			}
 			unset($graph);
+
+			/*
+			// TODO XXX: just stuffing some debug code here temporarily while working on block diagram code...
+			$graph = new pts_BlockDiagramGraph($result_file);
+			$graph->renderGraph();
+			$graph->svg_dom->output($save_to_dir . '/result-graphs/blocks.BILDE_EXTENSION');
+			*/
 		}
 
 		// Save XSL
@@ -1201,7 +1219,7 @@ class pts_client
 						pts_client::$display->generic_error('Argument Missing.');
 					}
 
-					echo 'CORRECT SYNTAX' . PHP_EOL . 'phoronix-test-suite ' . str_replace('_', '-', $command_alias) . ' ' . implode(' ', $argument_checks) . PHP_EOL . PHP_EOL;
+					echo 'CORRECT SYNTAX:' . PHP_EOL . 'phoronix-test-suite ' . str_replace('_', '-', $command_alias) . ' ' . implode(' ', $argument_checks) . PHP_EOL . PHP_EOL;
 
 					if(method_exists($command, 'invalid_command'))
 					{
@@ -1317,7 +1335,14 @@ class pts_client
 
 			if(!empty($pci_prev) && is_array($pci_prev) && is_array($pci))
 			{
-				$pci = array_diff($pci, $pci_prev);
+				if($pci == $pci_prev)
+				{
+					$pci = null;
+				}
+				else
+				{
+					$pci = array_diff($pci, $pci_prev);
+				}
 			}
 
 			if(!empty($pci))
@@ -1330,12 +1355,7 @@ class pts_client
 			$usb_prev = $pso->read_object('global_reported_usb');
 			$pso->add_object('global_reported_usb', $usb);
 
-			if(!empty($usb_prev) && is_array($usb_prev) && is_array($usb))
-			{
-				$usb = array_diff($usb, $usb_prev);
-			}
-
-			if(!empty($usb))
+			if(!empty($usb_prev) && is_array($usb_prev) && is_array($usb) && $usb != $usb_prev)
 			{
 				pts_openbenchmarking_client::upload_usb_data($usb);
 			}
@@ -1437,7 +1457,7 @@ class pts_client
 	{
 		return getenv($var);
 	}
-	public static function pts_set_environmental_variable($name, $value)
+	public static function pts_set_environment_variable($name, $value)
 	{
 		// Sets an environmental variable
 		return getenv($name) == false && putenv($name . '=' . $value);
@@ -1624,7 +1644,7 @@ class pts_client
 				{
 					$error_string = 'Undefined: ' . substr($error_string, ($x + 2));
 				}
-				else if(strpos($error_string, 'Name or service not known') !== false || strpos($error_string, 'HTTP request failed') !== false || strpos($error_string, 'fopen') !== false || strpos($error_string, 'file_get_contents') !== false)
+				else if(strpos($error_string, 'Name or service not known') !== false || strpos($error_string, 'HTTP request failed') !== false || strpos($error_string, 'fopen') !== false || strpos($error_string, 'file_get_contents') !== false || strpos($error_string, 'Directory not empty') !== false)
 				{
 					// Don't report network errors
 					return;
@@ -1668,7 +1688,7 @@ class pts_client
 				break;
 		}
 
-		echo PHP_EOL . '[' . $error_type . '] ' . $error_string . (pts_client::is_client_debug_mode() ? ' in ' . basename($error_file) . ':' . $error_line : null) . PHP_EOL;
+		echo '[' . $error_type . '] ' . $error_string . (pts_client::is_client_debug_mode() ? ' in ' . basename($error_file) . ':' . $error_line : null) . PHP_EOL;
 		return;
 	}
 	public static function is_client_debug_mode()
