@@ -37,7 +37,7 @@ class pts_test_install_manager
 	{
 		$added = false;
 
-		if(($e = pts_client::read_env('SKIP_TESTS')) != false && in_array($test_profile->get_identifier(false), pts_strings::comma_explode($e)))
+		if(($e = pts_client::read_env('SKIP_TESTS')) != false && (in_array($test_profile->get_identifier(false), pts_strings::comma_explode($e)) || in_array($test_profile->get_identifier(true), pts_strings::comma_explode($e))))
 		{
 			//pts_client::$display->test_install_error($test_profile->get_identifier() . ' is being skipped from installation.');
 		}
@@ -201,6 +201,7 @@ class pts_test_install_manager
 			{
 				$download_cache_dirs = array_merge(
 				pts_file_io::glob('/media/*/download-cache/'),
+				pts_file_io::glob('/run/media/*/*/download-cache/'),
 				pts_file_io::glob('/Volumes/*/download-cache/')
 				);
 
