@@ -42,7 +42,7 @@ class pts_test_installer
 		// Install tests
 		if(!is_writable(pts_client::test_install_root_path()))
 		{
-			echo PHP_EOL . 'ERROR: The test installation directory is not writable.' . PHP_EOL . 'Location: ' . pts_client::test_install_root_path() . PHP_EOL;
+			trigger_error('The test installation directory is not writable.' . PHP_EOL . 'Location: ' . pts_client::test_install_root_path(), E_USER_ERROR);
 			return false;
 		}
 
@@ -396,7 +396,7 @@ class pts_test_installer
 		{
 			// Handle C/C++ compilers for this external dependency
 			$compilers['CC'] = array(pts_strings::first_in_string(pts_client::read_env('CC'), ' '), 'gcc', 'clang', 'icc', 'pcc');
-			$compilers['CXX'] = array(pts_strings::first_in_string(pts_client::read_env('CXX'), ' '), 'g++', 'clang++');
+			$compilers['CXX'] = array(pts_strings::first_in_string(pts_client::read_env('CXX'), ' '), 'g++', 'clang++', 'cpp');
 		}
 		if($test_install_request === false || in_array('fortran-compiler', $test_install_request->test_profile->get_dependencies()))
 		{
@@ -543,10 +543,8 @@ class pts_test_installer
 					unset($compiler_lines[$l]);
 					continue;
 				}
-//echo $compiler_line;
-//echo PHP_EOL . 'O: ' . $o;
 			}
-//print_r($compiler_lines);
+
 			if(!empty($compiler_lines))
 			{
 				$compiler_line = array_pop($compiler_lines);
