@@ -139,7 +139,7 @@ class pts_test_run_manager
 			}
 		}
 
-		// No reason to increase the run count evidently
+		// No reason to increase the run count with none of the previous checks requesting otherwise
 		return false;
 	}
 	protected function add_test_result_object(&$test_result)
@@ -166,24 +166,17 @@ class pts_test_run_manager
 
 		return $identifiers;
 	}
-	public function get_estimated_run_time()
+	public function get_estimated_run_time($index = -1)
 	{
-		return $this->calculate_estimated_run_time(0);
-	}
-	public function get_estimated_run_time_remaining()
-	{
-		return $this->calculate_estimated_run_time($this->last_test_run_index);
-	}
-	private function calculate_estimated_run_time($index = 0)
-	{
-		$estimated_time = 0;
-
-		if(isset($this->tests_to_run[$index]))
+		if($index == -1)
 		{
-			for($i = $index; $i < count($this->tests_to_run); $i++)
-			{
-				$estimated_time += $this->tests_to_run[$i]->test_profile->get_estimated_run_time();
-			}
+			$index = $this->last_test_run_index;
+		}
+
+		$estimated_time = 0;
+		for($i = $index; $i < count($this->tests_to_run); $i++)
+		{
+			$estimated_time += $this->tests_to_run[$i]->test_profile->get_estimated_run_time();
 		}
 
 		return $estimated_time;
@@ -240,7 +233,6 @@ class pts_test_run_manager
 	public function result_already_contains_identifier()
 	{
 		$result_file = new pts_result_file($this->file_name);
-
 		return in_array($this->results_identifier, $result_file->get_system_identifiers());
 	}
 	public function set_save_name($save_name, $is_new_save = true)
@@ -293,49 +285,38 @@ class pts_test_run_manager
 		}
 
 		// Prompt to save a file when running a test
-		$proposed_name = null;
-		$custom_title = null;
+		$save_name = null;
 
 		if(($env = pts_client::read_env('TEST_RESULTS_NAME')))
 		{
-			$custom_title = $env;
-			$proposed_name = self::clean_save_name($env);
+			$save_name = $env;
 			//echo 'Saving Results To: ' . $proposed_name . PHP_EOL;
 		}
 
 		if((pts_c::$test_flags ^ pts_c::batch_mode) || pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/PromptSaveName', 'FALSE'))
 		{
 			$is_reserved_word = false;
-
 			// Be of help to the user by showing recently saved test results
-			self::recently_saved_test_results();
+			if($save_name == null)
+			{
+				self::recently_saved_test_results();
 
-			while(empty($proposed_name) || ($is_reserved_word = pts_types::is_test_or_suite($proposed_name)))
+			}
+
+			while(empty($save_name) || ($is_reserved_word = pts_types::is_test_or_suite($save_name)))
 			{
 				if($is_reserved_word)
 				{
-					echo PHP_EOL . 'The name of the saved file cannot be the same as a test/suite: ' . $proposed_name . PHP_EOL;
+					echo PHP_EOL . 'The name of the saved file cannot be the same as a test/suite: ' . $save_name . PHP_EOL;
 					$is_reserved_word = false;
 				}
 
 				pts_client::$display->generic_prompt('Enter a name to save these results under: ');
-				$proposed_name = pts_user_io::read_user_input();
-				$custom_title = $proposed_name;
-				$proposed_name = self::clean_save_name($proposed_name);
+				$save_name = pts_user_io::read_user_input();
 			}
 		}
 
-		if(empty($proposed_name))
-		{
-			$proposed_name = date('Y-m-d-Hi');
-		}
-		if(empty($custom_title))
-		{
-			$custom_title = $proposed_name;
-		}
-
-		$this->file_name = $proposed_name;
-		$this->file_name_title = $custom_title;
+		$this->set_save_name($save_name);
 	}
 	public function prompt_results_identifier()
 	{
@@ -411,7 +392,48 @@ class pts_test_run_manager
 
 		if(empty($results_identifier))
 		{
-			$results_identifier = date('Y-m-d H:i');
+			// If the save result identifier is empty, try to come up with something based upon the tests being run.
+			$subsystem_r = array();
+			$subsystems_to_test = $this->subsystems_under_test();
+
+			if(pts_result_file::is_test_result_file($this->file_name))
+			{
+				$result_file = new pts_result_file($this->file_name);
+				$result_file_intent = pts_result_file_analyzer::analyze_result_file_intent($result_file);
+
+				if(is_array($result_file_intent) && $result_file_intent[0] != 'Unknown')
+				{
+					array_unshift($subsystems_to_test, $result_file_intent[0]);
+				}
+			}
+
+			foreach($subsystems_to_test as $subsystem)
+			{
+				$components = pts_result_file_analyzer::system_component_string_to_array(phodevi::system_hardware(true) . ', ' . phodevi::system_software(true));
+				if(isset($components[$subsystem]))
+				{
+					$subsystem_name = pts_strings::trim_search_query($components[$subsystem]);
+
+					if(phodevi::is_vendor_string($subsystem_name) && !in_array($subsystem_name, $subsystem_r))
+					{
+						array_push($subsystem_r, $subsystem_name);
+					}
+					if(isset($subsystem_r[2]) || isset($subsystem_name[19]))
+					{
+						break;
+					}
+				}
+			}
+
+			if(isset($subsystem_r[0]))
+			{
+				$results_identifier = implode(' - ', $subsystem_r);
+			}
+
+			if(empty($results_identifier))
+			{
+				$results_identifier = date('Y-m-d H:i');
+			}
 		}
 
 		$this->results_identifier = $results_identifier;
@@ -423,10 +445,6 @@ class pts_test_run_manager
 
 		return $results_identifier;
 	}
-	public function result_file_setup()
-	{
-		$this->result_file_writer = new pts_result_file_writer($this->get_results_identifier());
-	}
 	public function get_test_run_position()
 	{
 		return $this->test_run_pos + 1;
@@ -583,12 +601,13 @@ class pts_test_run_manager
 			// removed count($result) > 0 in the move to pts_test_result
 			if(count($test_run_request) > 0 && ((is_numeric($end_result) && $end_result > 0) || (!is_numeric($end_result) && isset($end_result[3]))))
 			{
+				pts_module_manager::module_process('__post_test_run_success', $test_run_request);
 				$test_identifier = $this->get_results_identifier();
 				$test_successful = true;
 
 				if(!empty($test_identifier))
 				{
-					// XXX : add to attributes JSON Here and TODO XXX then pass to the result_file_writer
+					// XXX : add to attributes JSON here
 					$json_report_attributes = null;
 
 					if(($t = $test_run_request->test_profile->test_installation->get_compiler_data()))
@@ -687,7 +706,7 @@ class pts_test_run_manager
 	{
 		if($this->do_save_results())
 		{
-			$this->result_file_setup();
+			$this->result_file_writer = new pts_result_file_writer($this->get_results_identifier());
 
 			if((pts_c::$test_flags ^ pts_c::is_recovering) && (!pts_result_file::is_test_result_file($this->get_file_name()) || $this->result_already_contains_identifier() == false))
 			{
@@ -695,29 +714,29 @@ class pts_test_run_manager
 				$this->result_file_writer->add_current_system_information();
 			}
 
-			$pso = new pts_storage_object(true, false);
-			$pso->add_object('test_run_manager', $this);
-			$pso->add_object('batch_mode', (pts_c::$test_flags & pts_c::batch_mode));
-			$pso->add_object('system_hardware', phodevi::system_hardware(false));
-			$pso->add_object('system_software', phodevi::system_software(false));
-
-			$pso->save_to_file(pts_client::setup_test_result_directory($this->get_file_name()) . '/objects.pt2so');
-			unset($pso);
+			pts_client::setup_test_result_directory($this->get_file_name());
 		}
 	}
 	protected function generate_json_system_attributes()
 	{
-		$json_notes = null;
 		$test_external_dependencies = array();
 		$test_hardware_types = array();
+		$test_internal_tags = array();
 
 		foreach($this->tests_to_run as $test_to_run)
 		{
 			$test_external_dependencies = array_merge($test_external_dependencies, $test_to_run->test_profile->get_dependencies());
+			$test_internal_tags = array_merge($test_internal_tags, $test_to_run->test_profile->get_internal_tags());
 			pts_arrays::unique_push($test_hardware_types, $test_to_run->test_profile->get_test_hardware_type());
 		}
 
-		if(in_array('build-utilities', $test_external_dependencies))
+		return self::pull_test_notes(false, $test_external_dependencies, $test_internal_tags, $test_hardware_types);
+	}
+	public static function pull_test_notes($show_all = false, $test_external_dependencies = array(), $test_internal_tags = array(), $test_hardware_types = array())
+	{
+		$notes = null;
+
+		if($show_all || in_array('build-utilities', $test_external_dependencies))
 		{
 			// So compiler tests were run....
 			$test = false;
@@ -730,27 +749,52 @@ class pts_test_run_manager
 
 				if(!empty($compiler_configuration))
 				{
-					$json_notes['compiler-configuration'] = $compiler_configuration;
+					$notes['compiler-configuration'] = $compiler_configuration;
 				}
 			}
 		}
-		if(in_array('Disk', $test_hardware_types))
+		if($show_all || in_array('OpenCL', $test_internal_tags))
+		{
+			// So OpenCL tests were run....
+			$gpu_compute_cores = phodevi::read_property('gpu', 'compute-cores');
+			if($gpu_compute_cores > 0)
+			{
+				$notes['graphics-compute-cores'] = $gpu_compute_cores;
+			}
+		}
+		if($show_all || in_array('Disk', $test_hardware_types))
 		{
 			// A disk test was run so report some disk information...
 			$disk_scheduler = phodevi::read_property('disk', 'scheduler');
 			if($disk_scheduler)
 			{
-				$json_notes['disk-scheduler'] = $disk_scheduler;
+				$notes['disk-scheduler'] = $disk_scheduler;
 			}
 
 			$mount_options = phodevi::read_property('disk', 'mount-options');
 			if(isset($mount_options['mount-options']) && $mount_options['mount-options'] != null)
 			{
-				$json_notes['disk-mount-options'] = $mount_options['mount-options'];
+				$notes['disk-mount-options'] = $mount_options['mount-options'];
+			}
+		}
+		if($show_all || in_array('Processor', $test_hardware_types) || in_array('System', $test_hardware_types))
+		{
+			$scaling_governor = phodevi::read_property('cpu', 'scaling-governor');
+			if($scaling_governor)
+			{
+				$notes['cpu-scaling-governor'] = $scaling_governor;
+			}
+		}
+		if($show_all || in_array('Graphics', $test_hardware_types))
+		{
+			$accel_2d = phodevi::read_property('gpu', '2d-acceleration');
+			if($accel_2d)
+			{
+				$notes['graphics-2d-acceleration'] = $accel_2d;
 			}
 		}
 
-		return $json_notes;
+		return $notes;
 	}
 	public function post_execution_process()
 	{
@@ -762,7 +806,6 @@ class pts_test_run_manager
 				return false;
 			}
 
-			pts_file_io::unlink(pts_client::setup_test_result_directory($this->get_file_name()) . '/objects.pt2so');
 			pts_file_io::delete(PTS_SAVE_RESULTS_PATH . $this->get_file_name() . '/test-logs/active/', null, true);
 
 			if((pts_c::$test_flags ^ pts_c::is_recovering) && (!pts_result_file::is_test_result_file($this->get_file_name()) || $this->result_already_contains_identifier() == false))
@@ -789,7 +832,7 @@ class pts_test_run_manager
 				}
 				else if((pts_c::$test_flags ^ pts_c::auto_mode))
 				{
-					$upload_results = pts_user_io::prompt_bool_input('Would you like to upload these results to OpenBenchmarking.org', true);
+					$upload_results = pts_user_io::prompt_bool_input('Would you like to upload the results to OpenBenchmarking.org', true);
 				}
 				else
 				{
@@ -802,7 +845,10 @@ class pts_test_run_manager
 
 					if(!empty($upload_url))
 					{
-						pts_client::display_web_page($upload_url, 'Do you want to launch OpenBenchmarking.org', true);
+						if((pts_c::$test_flags ^ pts_c::auto_mode) && pts_openbenchmarking_client::auto_upload_results() == false)
+						{
+							pts_client::display_web_page($upload_url, 'Do you want to launch OpenBenchmarking.org', true);
+						}
 					}
 					else
 					{
@@ -954,6 +1000,15 @@ class pts_test_run_manager
 	{
 		$this->run_description = $description == null ? self::auto_generate_description() : $description;
 	}
+	public function subsystems_under_test()
+	{
+		$subsystems_to_test = array();
+		foreach($this->tests_to_run as $test_run_request)
+		{
+			pts_arrays::unique_push($subsystems_to_test, $test_run_request->test_profile->get_test_hardware_type());
+		}
+		return $subsystems_to_test;
+	}
 	protected function auto_generate_description()
 	{
 
@@ -980,13 +1035,7 @@ class pts_test_run_manager
 		}
 
 		$auto_description = 'Running ' . implode(', ', array_unique($this->get_tests_to_run_identifiers()));
-		$subsystems_to_test = array();
-
-		foreach($this->tests_to_run as $test_run_request)
-		{
-			array_push($subsystems_to_test, $test_run_request->test_profile->get_test_hardware_type());
-		}
-		$subsystems_to_test = array_unique($subsystems_to_test);
+		$subsystems_to_test = $this->subsystems_under_test();
 
 		// TODO: hook into $hw_components and $sw_components for leveraging existing result file data for comparisons already in existent
 		// dropped: count($subsystems_to_test) == 1 && $
@@ -1043,9 +1092,12 @@ class pts_test_run_manager
 	}
 	public function save_results_prompt()
 	{
-		pts_client::$display->generic_heading('System Information');
-		echo 'Hardware:' . PHP_EOL . phodevi::system_hardware(true) . PHP_EOL . PHP_EOL;
-		echo 'Software:' . PHP_EOL . phodevi::system_software(true) . PHP_EOL . PHP_EOL;
+		if((pts_c::$test_flags ^ pts_c::auto_mode))
+		{
+			pts_client::$display->generic_heading('System Information');
+			echo 'Hardware:' . PHP_EOL . phodevi::system_hardware(true) . PHP_EOL . PHP_EOL;
+			echo 'Software:' . PHP_EOL . phodevi::system_software(true) . PHP_EOL . PHP_EOL;
+		}
 
 		if(($this->prompt_save_results || $this->force_save_results) && count($this->tests_to_run) > 0) // or check for DO_NOT_SAVE_RESULTS == false
 		{
@@ -1077,19 +1129,22 @@ class pts_test_run_manager
 				}
 
 				// Prompt Description
-				if((pts_c::$test_flags ^ pts_c::auto_mode) && ((pts_c::$test_flags ^ pts_c::batch_mode) || pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/PromptForTestDescription', 'FALSE')))
+				if((pts_c::$test_flags ^ pts_c::batch_mode) || pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/PromptForTestDescription', 'FALSE'))
 				{
 					if($this->run_description == null)
 					{
 						$this->run_description = 'N/A';
 					}
 
-					if(pts_client::read_env('TEST_RESULTS_DESCRIPTION') != null)
+					if(pts_client::read_env('TEST_RESULTS_DESCRIPTION'))
 					{
-						$this->run_description = pts_client::read_env('TEST_RESULTS_DESCRIPTION');
-						echo 'Test Description: ' . $this->run_description . PHP_EOL;
+						if(strlen(pts_client::read_env('TEST_RESULTS_DESCRIPTION')) > 1)
+						{
+							$this->run_description = pts_client::read_env('TEST_RESULTS_DESCRIPTION');
+							echo 'Test Description: ' . $this->run_description . PHP_EOL;
+						}
 					}
-					else
+					else if((pts_c::$test_flags ^ pts_c::auto_mode))
 					{
 						pts_client::$display->generic_heading('If you wish, enter a new description below to better describe this result set / system configuration under test.' . PHP_EOL . 'Press ENTER to proceed without changes.');
 						echo 'Current Description: ' . $this->run_description . PHP_EOL . PHP_EOL . 'New Description: ';
@@ -1333,9 +1388,39 @@ class pts_test_run_manager
 			}
 		}
 
+		// AlwaysUploadResultsToOpenBenchmarking AutoSortRunQueue
+		if(pts_config::read_bool_config('PhoronixTestSuite/Options/Testing/AutoSortRunQueue', 'TRUE') && $this->force_save_results == false)
+		{
+			// Not that it matters much, but if $this->force_save_results is set that means likely running from a result file...
+			// so if running a result file, don't change the ordering of the existing results
+
+			// Sort the run order so that all tests that are similar are grouped together, etc
+			usort($this->tests_to_run, array('pts_test_run_manager', 'cmp_result_object_sort'));
+		}
+
 		$this->prompt_save_results = $run_contains_a_no_result_type == false || $unique_test_count > 1;
 		$this->force_save_results = $this->force_save_results || $request_results_save;
 	}
+	public static function cmp_result_object_sort($a, $b)
+	{
+		$a_comp = $a->test_profile->get_test_hardware_type() . $a->test_profile->get_test_software_type() . $a->test_profile->get_internal_tags_raw() . $a->test_profile->get_result_scale_formatted() . $a->test_profile->get_identifier(true);
+		$b_comp = $b->test_profile->get_test_hardware_type() . $b->test_profile->get_test_software_type() . $b->test_profile->get_internal_tags_raw() . $b->test_profile->get_result_scale_formatted() . $b->test_profile->get_identifier(true);
+
+		if($a_comp == $b_comp)
+		{
+			// So it's the same test being compared... try to sort in ascending order (such that 800 x 600 resolution comes before 1024 x 768), below way is an attempt to recognize such in weird manner
+			if(strlen($a->get_arguments_description()) == strlen($b->get_arguments_description()))
+			{
+				return strcmp($a->get_arguments_description(), $b->get_arguments_description());
+			}
+			else
+			{
+				return strcmp(strlen($a->get_arguments_description()), strlen($b->get_arguments_description()));
+			}
+		}
+
+		return strcmp($a_comp, $b_comp);
+	}
 	public static function test_profile_system_compatibility_check(&$test_profile, $report_errors = false)
 	{
 		$valid_test_profile = true;
