@@ -21,13 +21,9 @@
 	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-if(PTS_IS_CLIENT && is_file('/proc/cpuinfo'))
-{
-	phodevi_cpu::$cpuinfo = PHP_EOL . file_get_contents('/proc/cpuinfo');
-}
-
 class phodevi_cpu extends phodevi_device_interface
 {
+	// TODO XXX: $cpuinfo is now useless and needs to be replaced by the VFS layer... update OpenBenchmarking.org accordingly
 	public static $cpuinfo = false;
 	private static $cpu_flags = -1;
 
@@ -50,6 +46,9 @@ class phodevi_cpu extends phodevi_device_interface
 			case 'core-count':
 				$property = new phodevi_device_property('cpu_core_count', phodevi::smart_caching);
 				break;
+			case 'scaling-governor':
+				$property = new phodevi_device_property('cpu_scaling_governor', phodevi::std_caching);
+				break;
 		}
 
 		return $property;
@@ -113,7 +112,7 @@ class phodevi_cpu extends phodevi_device_interface
 			//$info = getenv('NUMBER_OF_PROCESSORS');
 		}
 
-		if($info == null && self::$cpuinfo)
+		if($info == null && isset(phodevi::$vfs->cpuinfo))
 		{
 			$info = self::cpuinfo_core_count();
 		}
@@ -124,6 +123,17 @@ class phodevi_cpu extends phodevi_device_interface
 	{
 		return self::cpu_default_frequency() * 1000;
 	}
+	public static function cpu_scaling_governor()
+	{
+		$scaling_governor = false;
+
+		if(is_file('/sys/devices/system/cpu/cpu0/cpufreq/scaling_governor'))
+		{
+			$scaling_governor = pts_file_io::file_get_contents('/sys/devices/system/cpu/cpu0/cpufreq/scaling_governor');
+		}
+
+		return $scaling_governor;
+	}
 	public static function is_genuine($cpu)
 	{
 		/*
@@ -143,7 +153,7 @@ class phodevi_cpu extends phodevi_device_interface
 			$info = pts_file_io::file_get_contents('/sys/devices/system/cpu/cpu' . $cpu_core . '/cpufreq/scaling_max_freq');
 			$info = intval($info) / 1000000;
 		}
-		else if(self::$cpuinfo) // fall back for those without cpufreq
+		else if(isset(phodevi::$vfs->cpuinfo)) // fall back for those without cpufreq
 		{
 			$cpu_mhz = self::read_cpuinfo_line('cpu MHz');
 			$info = $cpu_mhz / 1000;
@@ -214,12 +224,12 @@ class phodevi_cpu extends phodevi_device_interface
 		// Returns the processor name / frequency information
 		$info = null;
 
-		if(self::$cpuinfo)
+		if(isset(phodevi::$vfs->cpuinfo))
 		{
-			$physical_cpu_ids = phodevi_linux_parser::read_cpuinfo('physical id', self::$cpuinfo);
+			$physical_cpu_ids = phodevi_linux_parser::read_cpuinfo('physical id');
 			$physical_cpu_count = count(array_unique($physical_cpu_ids));
 
-			$cpu_strings = phodevi_linux_parser::read_cpuinfo(array('model name', 'Processor'), self::$cpuinfo);
+			$cpu_strings = phodevi_linux_parser::read_cpuinfo(array('model name', 'Processor'));
 			$cpu_strings_unique = array_unique($cpu_strings);
 
 			if($physical_cpu_count == 1 || empty($physical_cpu_count))
@@ -353,20 +363,22 @@ class phodevi_cpu extends phodevi_device_interface
 	public static function get_cpu_feature_constants()
 	{
 		return array(
-			'sse2' => 2, // SSE 2
-			'sse3' => 4, // SSE 3
-			'sse4a' => 8, // SSE 4a
-			'sse4_1' => 16, // SSE 4.1
-			'sse4_2' => 32, // SSE 4.2
-			'sse5' => 64, // SSE 5
-			'avx' => 128, // AVX
-			'aes' => 256, // AES
-			'epb' => 512, // EPB
-			'svm' => 1024, // AMD SVM (Virtualization)
-			'vmx' => 2048, // Intel Virtualization
-			'xop' => 4096, // AMD XOP Instruction Set
-			'fma3' => 8192, // FMA3 Instruction Set
-			'fma4' => 16384 // FMA4 Instruction Set
+			'sse2' => (1 << 1), // SSE 2
+			'sse3' => (1 << 2), // SSE 3
+			'sse4a' => (1 << 3), // SSE 4a
+			'sse4_1' => (1 << 4), // SSE 4.1
+			'sse4_2' => (1 << 5), // SSE 4.2
+			'sse5' => (1 << 6), // SSE 5
+			'avx' => (1 << 7), // AVX
+			'aes' => (1 << 8), // AES
+			'epb' => (1 << 9), // EPB
+			'svm' => (1 << 10), // AMD SVM (Virtualization)
+			'vmx' => (1 << 11), // Intel Virtualization
+			'xop' => (1 << 12), // AMD XOP Instruction Set
+			'fma3' => (1 << 13), // FMA3 Instruction Set
+			'fma4' => (1 << 14), // FMA4 Instruction Set
+			'rdrand' => (1 << 15), // Intel Bull Mountain RDRAND - Ivy Bridge
+			'fsgsbase' => ( 1 << 16) // FSGSBASE - Ivy Bridge AVX
 			);
 	}
 	public static function get_cpu_feature_constant($constant)
@@ -378,10 +390,11 @@ class phodevi_cpu extends phodevi_device_interface
 	public static function read_cpuinfo_line($key, $from_start = true)
 	{
 		$line = false;
+		$key .= "\t";
 
-		if(($from_start && ($key_pos = strpos(self::$cpuinfo, PHP_EOL . $key)) !== false) || ($key_pos = strrpos(self::$cpuinfo, PHP_EOL . $key)) !== false)
+		if(isset(phodevi::$vfs->cpuinfo) && ($from_start && ($key_pos = strpos(phodevi::$vfs->cpuinfo, PHP_EOL . $key)) !== false) || ($key_pos = strrpos(phodevi::$vfs->cpuinfo, PHP_EOL . $key)) !== false)
 		{
-			$line = substr(self::$cpuinfo, $key_pos);
+			$line = substr(phodevi::$vfs->cpuinfo, $key_pos);
 			$line = substr($line, strpos($line, ':') + 1);
 			$line = trim(substr($line, 0, strpos($line, PHP_EOL)));
 		}
@@ -414,6 +427,7 @@ class phodevi_cpu extends phodevi_device_interface
 	public static function instruction_set_extensions()
 	{
 		$constants = self::get_cpu_feature_constants();
+		self::set_cpu_feature_flags();
 		$cpu_flags = self::get_cpu_flags();
 		$extension_string = null;
 
@@ -427,7 +441,7 @@ class phodevi_cpu extends phodevi_device_interface
 		}
 
 		// Check for other instruction sets
-		foreach(array('avx', 'xop', 'fma3', 'fma4') as $instruction_set)
+		foreach(array('avx', 'xop', 'fma3', 'fma4', 'rdrand', 'fsgsbase') as $instruction_set)
 		{
 			if(($cpu_flags & self::get_cpu_feature_constant($instruction_set)))
 			{
@@ -454,6 +468,19 @@ class phodevi_cpu extends phodevi_device_interface
 
 		return $virtualitzation_technology;
 	}
+	public static function lscpu_l2_cache()
+	{
+		$l2_cache = false;
+
+		if(isset(phodevi::$vfs->lscpu) && ($t = strpos(phodevi::$vfs->lscpu, 'L2 cache:')))
+		{
+			$lscpu = substr(phodevi::$vfs->lscpu, $t + strlen('L2 cache:') + 1);
+			$lscpu = substr($lscpu, 0, strpos($lscpu, PHP_EOL));
+			$l2_cache = trim($lscpu);
+		}
+
+		return $l2_cache;
+	}
 	public static function cpuinfo_core_count()
 	{
 		$core_count = self::read_cpuinfo_line('cpu cores');
