@@ -52,7 +52,7 @@ class phodevi_gpu extends phodevi_device_interface
 				$property = new phodevi_device_property('gpu_compute_cores', phodevi::smart_caching);
 				break;
 			case 'available-modes':
-				$property = new phodevi_device_property('gpu_available_modes', phodevi::smart_caching);
+				$property = new phodevi_device_property('gpu_available_modes', phodevi::std_caching);
 				break;
 			case 'screen-resolution':
 				$property = new phodevi_device_property('gpu_screen_resolution', phodevi::std_caching);
@@ -60,10 +60,44 @@ class phodevi_gpu extends phodevi_device_interface
 			case 'screen-resolution-string':
 				$property = new phodevi_device_property('gpu_screen_resolution_string', phodevi::std_caching);
 				break;
+			case '2d-acceleration':
+				$property = new phodevi_device_property('gpu_2d_acceleration', phodevi::std_caching);
+				break;
 		}
 
 		return $property;
 	}
+	public static function gpu_2d_acceleration()
+	{
+		$xorg_log = isset(phodevi::$vfs->xorg_log) ? phodevi::$vfs->xorg_log : false;
+		$accel_2d = false;
+
+		if($xorg_log)
+		{
+			if(strpos($xorg_log, 'EXA(0)'))
+			{
+				$accel_2d = 'EXA';
+			}
+			else if(stripos($xorg_log, 'GLAMOR acceleration'))
+			{
+				$accel_2d = 'GLAMOR';
+			}
+			else if(strpos($xorg_log, 'SNA initialized'))
+			{
+				$accel_2d = 'SNA';
+			}
+			else if(strpos($xorg_log, 'UXA(0)'))
+			{
+				$accel_2d = 'UXA';
+			}
+			else if(strpos($xorg_log, 'shadowfb'))
+			{
+				$accel_2d = 'ShadowFB';
+			}
+		}
+
+		return $accel_2d;
+	}
 	public static function set_property($identifier, $args)
 	{
 		switch($identifier)
@@ -473,7 +507,8 @@ class phodevi_gpu extends phodevi_device_interface
 			// Fallback to providing stock modes
 			$stock_modes = array(
 				array(800, 600), array(1024, 768),
-				array(1280, 1024), array(1400, 1050), 
+				array(1280, 1024), array(1400, 900),
+				array(1400, 1050), array(1600, 900),
 				array(1680, 1050), array(1600, 1200),
 				array(1920, 1080), array(2560, 1600));
 			$available_modes = array();
@@ -487,6 +522,11 @@ class phodevi_gpu extends phodevi_device_interface
 			}
 		}
 
+		if(!in_array(phodevi::read_property('gpu', 'screen-resolution'), $available_modes))
+		{
+			array_push($available_modes, phodevi::read_property('gpu', 'screen-resolution'));
+		}
+
 		foreach($available_modes as $mode_index => $mode)
 		{
 			$this_ratio = pts_math::set_precision($mode[0] / $mode[1], 2);
@@ -600,18 +640,12 @@ class phodevi_gpu extends phodevi_device_interface
 			}
 		}
 
-		if($video_ram == -1 && is_file('/var/log/Xorg.0.log'))
+		if($video_ram == -1 && isset(phodevi::$vfs->xorg_log))
 		{
 			// Attempt Video RAM detection using X log
 			// fglrx driver reports video memory to: (--) fglrx(0): VideoRAM: XXXXXX kByte, Type: DDR
 			// xf86-video-ati, xf86-video-intel, and xf86-video-radeonhd also report their memory information in a similar format
-
-			$info = shell_exec('cat /var/log/Xorg.0.log | grep -i VideoRAM');
-
-			if(empty($info))
-			{
-				$info = shell_exec('cat /var/log/Xorg.0.log | grep "Video RAM"');
-			}
+			$info = phodevi::$vfs->xorg_log;
 
 			if(($pos = stripos($info, 'RAM:') + 5) > 5 || ($pos = strpos($info, 'RAM=') + 4) > 4)
 			{
@@ -623,16 +657,16 @@ class phodevi_gpu extends phodevi_device_interface
 					$info = substr($info, 0, $cut);
 				}
 
-				if($info > 65535)
+				if(is_numeric($info) && $info > 65535)
 				{
 					$video_ram = intval($info) / 1024;
 				}
 			}
 		}
-		if($video_ram == -1 && pts_client::executable_in_path('dmesg'))
+		if($video_ram == -1 && isset(phodevi::$vfs->dmesg))
 		{
 			// Fallback to try to find vRAM from dmesg
-			$info = shell_exec('dmesg 2> /dev/null');
+			$info = phodevi::$vfs->dmesg;
 
 			if(($x = strpos($info, 'Detected VRAM RAM=')) !== false)
 			{
@@ -728,7 +762,7 @@ class phodevi_gpu extends phodevi_device_interface
 			switch(phodevi::read_property('system', 'display-driver'))
 			{
 				case 'nouveau':
-					foreach(pts_file_io::glob('/sys/class/drm/card0/device/performance_level*') as $performance_level)
+					if(is_file('/sys/class/drm/card0/device/performance_level'))
 					{
 						/*
 							EXAMPLE OUTPUTS:
@@ -737,14 +771,14 @@ class phodevi_gpu extends phodevi_device_interface
 							c: memory 333MHz core 500MHz shader 1250MHz
 						*/
 
-						$performance_level = pts_file_io::file_get_contents($performance_level);
+						$performance_level = pts_file_io::file_get_contents('/sys/class/drm/card0/device/performance_level');
 						$performance_level = explode(' ', $performance_level);
 
 						$core_string = array_search('core', $performance_level);
 						if($core_string !== false && isset($performance_level[($core_string + 1)]))
 						{
 							$core_string = str_ireplace('MHz', null, $performance_level[($core_string + 1)]);
-							if(is_numeric($core_string) && $core_string > $core_freq)
+							if(is_numeric($core_string))
 							{
 								$core_freq = $core_string;
 							}
@@ -754,7 +788,7 @@ class phodevi_gpu extends phodevi_device_interface
 						if($mem_string !== false && isset($performance_level[($mem_string + 1)]))
 						{
 							$mem_string = str_ireplace('MHz', null, $performance_level[($mem_string + 1)]);
-							if(is_numeric($mem_string) && $mem_string > $mem_freq)
+							if(is_numeric($mem_string))
 							{
 								$mem_freq = $mem_string;
 							}
@@ -762,11 +796,16 @@ class phodevi_gpu extends phodevi_device_interface
 					}
 					break;
 				case 'radeon':
-					if(is_file('/sys/kernel/debug/dri/0/radeon_pm_info'))
+					if(isset(phodevi::$vfs->radeon_pm_info))
 					{
 						// radeon_pm_info should be present with Linux 2.6.34+
-						foreach(pts_strings::trim_explode("\n", pts_file_io::file_get_contents('/sys/kernel/debug/dri/0/radeon_pm_info')) as $pm_line)
+						foreach(pts_strings::trim_explode("\n", phodevi::$vfs->radeon_pm_info) as $pm_line)
 						{
+							if($pm_line == null)
+							{
+								continue;
+							}
+
 							list($descriptor, $value) = pts_strings::colon_explode($pm_line);
 
 							switch($descriptor)
@@ -783,15 +822,25 @@ class phodevi_gpu extends phodevi_device_interface
 					else
 					{
 						// Old ugly way of handling the clock information
-						$log_parse = shell_exec('cat /var/log/Xorg.0.log 2>&1 | grep " Clock: "');
+						$log_parse = isset(phodevi::$vfs->xorg_log) ? phodevi::$vfs->xorg_log : null;
 
-						$core_freq = substr($log_parse, strpos($log_parse, 'Default Engine Clock: ') + 22);
-						$core_freq = substr($core_freq, 0, strpos($core_freq, "\n"));
-						$core_freq = is_numeric($core_freq) ? $core_freq / 1000 : 0;
+						if(($engine_clock = strpos($log_parse, 'Default Engine Clock: ')))
+						{
+							$core_freq = substr($log_parse, $engine_clock + 22);
+							$core_freq = substr($core_freq, 0, strpos($core_freq, "\n"));
+							$core_freq = is_numeric($core_freq) ? $core_freq / 1000 : 0;
 
-						$mem_freq = substr($log_parse, strpos($log_parse, 'Default Memory Clock: ') + 22);
-						$mem_freq = substr($mem_freq, 0, strpos($mem_freq, "\n"));
-						$mem_freq = is_numeric($mem_freq) ? $mem_freq / 1000 : 0;
+							if($core_freq && ($mem_clock = strpos($log_parse, 'Default Memory Clock: ')))
+							{
+								$mem_freq = substr($log_parse, $mem_clock + 22);
+								$mem_freq = substr($mem_freq, 0, strpos($mem_freq, "\n"));
+								$mem_freq = is_numeric($mem_freq) ? $mem_freq / 1000 : 0;
+							}
+							else
+							{
+								$core_freq = 0;
+							}
+						}
 					}				
 					break;
 				case 'intel':
@@ -808,9 +857,9 @@ class phodevi_gpu extends phodevi_device_interface
 					}
 
 					// Fallback to base frequency
-					if($core_freq == 0 && is_file('/sys/kernel/debug/dri/0/i915_cur_delayinfo'))
+					if($core_freq == 0 && isset(phodevi::$vfs->i915_cur_delayinfo))
 					{
-						$i915_cur_delayinfo = file_get_contents('/sys/kernel/debug/dri/0/i915_cur_delayinfo');
+						$i915_cur_delayinfo = phodevi::$vfs->i915_cur_delayinfo;
 						$freq = strpos($i915_cur_delayinfo, 'Max non-overclocked (RP0) frequency: ');
 
 						if($freq === false)
@@ -921,17 +970,38 @@ class phodevi_gpu extends phodevi_device_interface
 				$info .= ' SLI';
 			}
 		}
-
-		if(phodevi::is_solaris())
+		else if(phodevi::is_solaris())
 		{
 			if(($cut = strpos($info, 'DRI ')) !== false)
 			{
 				$info = substr($info, ($cut + 4));
 			}
+
 			if(($cut = strpos($info, ' Chipset')) !== false)
 			{
 				$info = substr($info, 0, $cut);
 			}
+
+			if($info == false && isset(phodevi::$vfs->xorg_log))
+			{
+				$xorg_log = phodevi::$vfs->xorg_log;
+				if(($x = strpos($xorg_log, '(0): Chipset: ')) !== false)
+				{
+					$xorg_log = substr($xorg_log, ($x + 14));
+					$xorg_log = str_replace(array('(R)', '"'), null, substr($xorg_log, 0, strpos($xorg_log, PHP_EOL)));
+
+					if(($c = strpos($xorg_log, '[')) || ($c = strpos($xorg_log, '(')))
+					{
+						$xorg_log = substr($xorg_log, 0, $c);
+					}
+
+					if(phodevi::is_product_string($xorg_log))
+					{
+						$info = $xorg_log;
+					}
+				}
+
+			}
 		}
 		else if(phodevi::is_bsd())
 		{
@@ -956,10 +1026,9 @@ class phodevi_gpu extends phodevi_device_interface
 				$info = $drm_info;
 			}
 
-			if($info == null && is_readable('/var/log/Xorg.0.log'))
+			if($info == null && isset(phodevi::$vfs->xorg_log))
 			{
-				$xorg_log = file_get_contents('/var/log/Xorg.0.log');
-
+				$xorg_log = phodevi::$vfs->xorg_log;
 				if(($e = strpos($xorg_log, ' at 01@00:00:0')) !== false)
 				{
 					$xorg_log = substr($xorg_log, 0, $e);
@@ -990,7 +1059,7 @@ class phodevi_gpu extends phodevi_device_interface
 					{
 						// Try to come up with a better non-generic string
 						$was_reset = false;
-						if(is_readable('/var/log/Xorg.0.log'))
+						if(isset(phodevi::$vfs->xorg_log))
 						{
 							/*
 							$ cat /var/log/Xorg.0.log | grep -i Chipset
@@ -1000,11 +1069,10 @@ class phodevi_gpu extends phodevi_device_interface
 							[     8.423] (--) intel(0): Chipset: "Sandybridge Mobile (GT2+)"
 							*/
 
-							$xorg_log = file_get_contents('/var/log/Xorg.0.log');
-
-							if(($x = strpos($xorg_log, 'intel(0): Chipset: ')) !== false)
+							$xorg_log = phodevi::$vfs->xorg_log;
+							if(($x = strpos($xorg_log, '(0): Chipset: ')) !== false)
 							{
-								$xorg_log = substr($xorg_log, ($x + 19));
+								$xorg_log = substr($xorg_log, ($x + 14));
 								$xorg_log = str_replace(array('(R)', '"'), null, substr($xorg_log, 0, strpos($xorg_log, PHP_EOL)));
 
 								if(stripos($xorg_log, 'Intel') === false)
@@ -1020,9 +1088,9 @@ class phodevi_gpu extends phodevi_device_interface
 								}
 							}
 						}
-						if($was_reset == false && is_readable('/sys/kernel/debug/dri/0/i915_capabilities'))
+						if($was_reset == false && isset(phodevi::$vfs->i915_capabilities))
 						{
-							$i915_caps = file_get_contents('/sys/kernel/debug/dri/0/i915_capabilities');
+							$i915_caps = phodevi::$vfs->i915_capabilities;
 							if(($x = strpos($i915_caps, 'gen: ')) !== false)
 							{
 								$gen = substr($i915_caps, ($x + 5));
@@ -1048,13 +1116,13 @@ class phodevi_gpu extends phodevi_device_interface
 				$info = substr($info, $start_pos + 5);
 			}
 
-			if(empty($info))
+			if(empty($info) && isset(phodevi::$vfs->xorg_log))
 			{
-				$log_parse = shell_exec('cat /var/log/Xorg.0.log 2>&1 | grep Chipset');
+				$log_parse = phodevi::$vfs->xorg_log;
 				$log_parse = substr($log_parse, strpos($log_parse, 'Chipset') + 8);
 				$log_parse = substr($log_parse, 0, strpos($log_parse, 'found'));
 
-				if(strpos($log_parse, '(--)') === false && strlen(str_replace(array('ATI', 'NVIDIA', 'VIA', 'Intel'), '', $log_parse)) != strlen($log_parse))
+				if(strpos($log_parse, '(--)') === false && strlen(str_ireplace(array('ATI', 'NVIDIA', 'VIA', 'Intel'), '', $log_parse)) != strlen($log_parse))
 				{
 					$info = $log_parse;
 				}
