@@ -231,9 +231,9 @@ class phodevi_system extends phodevi_device_interface
 			switch($fs)
 			{
 				case 'ext2/ext3':
-					if(is_readable('/proc/mounts'))
+					if(isset(phodevi::$vfs->mounts))
 					{
-						$fstab = file_get_contents('/proc/mounts');
+						$fstab = phodevi::$vfs->mounts;
 						$fstab = str_replace('/boot ', 'IGNORE', $fstab);
 
 						$using_ext2 = strpos($fstab, ' ext2') !== false;
@@ -271,6 +271,24 @@ class phodevi_system extends phodevi_device_interface
 				case 'UFSD_NTFS_COMPR':
 					$fs = 'NTFS';
 					break;
+				case 'ecryptfs':
+					if(isset(phodevi::$vfs->mounts))
+					{
+						// An easy attempt to determine what file-system is underneath ecryptfs if being compared
+						// For now just attempt to figure out the root file-system.
+						if(($s = strrpos(phodevi::$vfs->mounts, ' / ')) !== false)
+						{
+							$s = substr(phodevi::$vfs->mounts, ($s + 3));
+							$s = substr($s, 0, strpos($s, ' '));
+
+
+							if($s != null && !isset($s[18]) && $s != 'rootfs'&& pts_strings::string_only_contains($s, pts_strings::CHAR_LETTER | pts_strings::CHAR_NUMERIC))
+							{
+								$fs = $s . ' (ecryptfs)';
+							}
+						}
+					}
+					break;
 				default:
 					if(substr($fs, 0, 9) == 'UNKNOWN (')
 					{
@@ -308,9 +326,9 @@ class phodevi_system extends phodevi_device_interface
 					break;
 			}
 
-			if(strpos($fs, 'UNKNOWN') !== false && is_readable('/proc/mounts'))
+			if(strpos($fs, 'UNKNOWN') !== false && isset(phodevi::$vfs->mounts))
 			{
-				$mounts = file_get_contents('/proc/mounts');
+				$mounts = phodevi::$vfs->mounts;
 				$fs_r = array();
 
 				$fs_checks = array(
@@ -417,6 +435,34 @@ class phodevi_system extends phodevi_device_interface
 		{
 			$virtualized = 'Parallels Virtualization';
 		}
+		else if(is_file('/sys/hypervisor/type'))
+		{
+			$type = pts_file_io::file_get_contents('/sys/hypervisor/type');
+			$version = array();
+
+			foreach(array('major', 'minor', 'extra') as $v)
+			{
+				if(is_file('/sys/hypervisor/version/' . $v))
+				{
+					$v = pts_file_io::file_get_contents('/sys/hypervisor/version/' . $v);
+				}
+				else
+				{
+					continue;
+				}
+
+				if($v != null)
+				{
+					if(!empty($version) && substr($v, 0, 1) != '.')
+					{
+						$v = '.' . $v;
+					}
+					array_push($version, $v);
+				}
+			}
+
+			$virtualized = ucwords($type) . ' ' . implode('', $version) . ' Hypervisor';
+		}
 
 		return $virtualized;
 	}
@@ -506,7 +552,8 @@ class phodevi_system extends phodevi_device_interface
 				$compiler_info = substr($compiler_info, ($cv_pos + 14));
 				$clang_version = substr($compiler_info, 0, strpos($compiler_info, ' '));
 
-				if(pts_strings::is_version($clang_version))
+				// XXX: the below check bypass now because e.g. Ubuntu appends '-ubuntuX', etc that breaks check
+				if(pts_strings::is_version($clang_version) || true)
 				{
 					// Also see if there is a Clang SVN tag to fetch
 					$compiler_info = substr($compiler_info, 0, strpos($compiler_info, PHP_EOL));
@@ -545,19 +592,28 @@ class phodevi_system extends phodevi_device_interface
 		{
 			// LLVM - Low Level Virtual Machine
 			// Reading the version from llvm-ld (the LLVM linker) should be safe as well for finding out version of LLVM in use
-			$info = trim(shell_exec('llvm-ld --version 2> /dev/null'));
+			$info = trim(shell_exec('llvm-ld -version 2> /dev/null'));
 
 			if(($s = strpos($info, 'version')) != false)
 			{
 				$info = substr($info, 0, strpos($info, PHP_EOL, $s));
 				$info = substr($info, (strrpos($info, ' ') + 1));
 
-				if(pts_strings::is_version($info))
+				if(pts_strings::is_version(str_replace('svn', null, $info)))
 				{
 					$compilers['llvmc'] = 'LLVM ' . $info;
 				}
 			}
 		}
+		else if(pts_client::executable_in_path('llvm-config'))
+		{
+			// LLVM - Low Level Virtual Machine config
+			$info = trim(shell_exec('llvm-config --version 2> /dev/null'));
+			if(pts_strings::is_version(str_replace('svn', null, $info)))
+			{
+				$compilers['llvmc'] = 'LLVM ' . $info;
+			}
+		}
 		else if(pts_client::executable_in_path('llvmc'))
 		{
 			// LLVM - Low Level Virtual Machine (llvmc)
@@ -586,6 +642,36 @@ class phodevi_system extends phodevi_device_interface
 			}
 		}
 
+		if(pts_client::executable_in_path('ioc'))
+		{
+			// Intel Offline Compiler (IOC) SDK for OpenCL
+			// -v e.g. : Intel(R) SDK for OpenCL* - Offline Compiler 2012 Command-Line Client, version 1.0.2
+			$info = trim(shell_exec('ioc -version 2>&1')) . ' ';
+
+			if(($s = strpos($info, 'Offline Compiler ')) != false)
+			{
+				$compilers['ioc'] = 'Intel IOC SDK';
+				$sv = substr($info, ($s + 17));
+				$sv = substr($sv, 0, strpos($sv, ' '));
+
+				if(is_numeric($sv))
+				{
+					$compilers['ioc'] .= ' ' . $sv;
+				}
+
+				if(($s = strpos($info, 'version ')) != false)
+				{
+					$sv = substr($info, ($s + 8));
+					$sv = substr($sv, 0, strpos($sv, ' '));
+
+					if(pts_strings::is_version($sv))
+					{
+						$compilers['ioc'] .= ' v' . $sv;
+					}
+				}
+			}
+		}
+
 		if(pts_client::executable_in_path('icc'))
 		{
 			// Intel C++ Compiler
@@ -603,10 +689,11 @@ class phodevi_system extends phodevi_device_interface
 			}
 		}
 
-		if(pts_client::executable_in_path('nvcc'))
+		if(($nvcc = pts_client::executable_in_path('nvcc')) || is_executable(($nvcc = '/usr/local/cuda/bin/nvcc')))
 		{
+			// Check outside of PATH too since by default the CUDA Toolkit goes to '/usr/local/cuda/' and relies upon user to update system
 			// NVIDIA CUDA Compiler Driver
-			$nvcc = shell_exec('nvcc --version 2>&1');
+			$nvcc = shell_exec($nvcc . ' --version 2>&1');
 			if(($s = strpos($nvcc, 'release ')) !== false)
 			{
 				$nvcc = str_replace(array(','), null, substr($nvcc, ($s + 8)));
@@ -910,7 +997,7 @@ class phodevi_system extends phodevi_device_interface
 		else if(pts_client::is_process_running('lxsession'))
 		{
 			$lx_output = trim(shell_exec('lxpanel --version'));
-			$version = substr($lx_output, strpos(' ', $lx_output) + 1);
+			$version = substr($lx_output, strpos($lx_output, ' ') + 1);
 
 			$desktop_environment = 'LXDE';
 			$desktop_version = $version;
@@ -933,6 +1020,22 @@ class phodevi_system extends phodevi_device_interface
 			$desktop_environment = 'Sugar';
 			$desktop_version = null; // TODO: where can the Sugar version be figured out?
 		}
+		else if(pts_client::is_process_running('openbox'))
+		{
+			$desktop_environment = 'Openbox';
+			$openbox_output = trim(shell_exec('openbox --version 2>&1'));
+
+			if(($openbox_d = stripos($openbox_output, 'Openbox ')) !== false)
+			{
+				$openbox_output = substr($openbox_output, ($openbox_d + 8));
+				$desktop_version = substr($openbox_output, 0, strpos($openbox_output, PHP_EOL));
+			}
+		}
+		else if(pts_client::is_process_running('cinnamon'))
+		{
+			$desktop_environment = 'Cinnamon';
+			$desktop_version = pts_strings::last_in_string(trim(shell_exec('cinnamon --version 2> /dev/null')));
+		}
 
 		if(!empty($desktop_environment))
 		{
@@ -1247,6 +1350,56 @@ class phodevi_system extends phodevi_device_interface
 			sort($cc);
 			$cc = implode(' ', $cc);
 		}
+		else if(($t = stripos($cc, 'clang')) !== false)
+		{
+			$cc = null;
+
+			// Clang doesn't report "configured with" but has other useful tid-bits...
+			if(($c = pts_client::executable_in_path('llvm-ld')))
+			{
+				$llvm_ld = shell_exec($c . ' -version 2>&1');
+				/*
+				EXAMPLE OUTPUT:
+					LLVM (http://llvm.org/):
+					  LLVM version 3.1svn
+					  Optimized build.
+					  Built Mar 23 2012 (08:53:34).
+					  Default target: x86_64-unknown-linux-gnu
+					  Host CPU: corei7-avx
+				*/
+
+				if(stripos($llvm_ld, 'build') && (stripos($llvm_ld, 'host') || stripos($llvm_ld, 'target')))
+				{
+					$llvm_ld = explode(PHP_EOL, $llvm_ld);
+
+					if(stripos($llvm_ld[0], 'http://'))
+					{
+						array_shift($llvm_ld);
+					}
+					if(stripos($llvm_ld[0], 'version'))
+					{
+						array_shift($llvm_ld);
+					}
+
+					foreach($llvm_ld as $i => &$line)
+					{
+						$line = trim($line);
+						if(substr($line, -1) == '.')
+						{
+							$line = substr($line, 0, -1);
+						}
+
+						if($line == null)
+						{
+							unset($llvm_ld[$i]);
+						}
+					}
+
+					$cc = implode('; ', $llvm_ld);
+				}
+			}
+
+		}
 		else
 		{
 			$cc = null;
