@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2011, Phoronix Media
-	Copyright (C) 2008 - 2011, Michael Larabel
+	Copyright (C) 2008 - 2012, Phoronix Media
+	Copyright (C) 2008 - 2012, Michael Larabel
 	phodevi_linux_parser.php: General parsing functions specific to Linux
 
 	This program is free software; you can redistribute it and/or modify
@@ -244,15 +244,15 @@ class phodevi_linux_parser
 	}
 	public static function read_ati_overdrive($attribute, $adapter = 0)
 	{
-		// Read ATI OverDrive information using aticonfig
+		// Read ATI OverDrive information
 		// OverDrive supported in fglrx 8.52+ drivers
 		$value = false;
 
-		if(pts_client::executable_in_path('aticonfig'))
+		if(($amdconfig = self::find_amdconfig()))
 		{
 			if($attribute == 'Temperature')
 			{
-				$info = shell_exec('aticonfig --adapter=' . $adapter . ' --od-gettemperature 2>&1');
+				$info = shell_exec($amdconfig . ' --adapter=' . $adapter . ' --od-gettemperature 2>&1');
 
 				if(($start = strpos($info, 'Temperature -')) !== false)
 				{
@@ -263,7 +263,7 @@ class phodevi_linux_parser
 			else if($attribute == 'FanSpeed')
 			{
 				// Right now there is no standardized interface to get the fan speed through besides the pplib command
-				$info = shell_exec('aticonfig --adapter=' . $adapter . ' --pplib-cmd \'get fanspeed 0\' 2>&1');
+				$info = shell_exec($amdconfig . ' --adapter=' . $adapter . ' --pplib-cmd \'get fanspeed 0\' 2>&1');
 
 				if(($start = strpos($info, 'Fan Speed:')) !== false)
 				{
@@ -278,7 +278,7 @@ class phodevi_linux_parser
 			}
 			else
 			{
-				$info = shell_exec('aticonfig --adapter=' . $adapter . ' --od-getclocks 2>&1');
+				$info = shell_exec($amdconfig . ' --adapter=' . $adapter . ' --od-getclocks 2>&1');
 
 				if(strpos($info, 'GPU') !== false)
 				{
@@ -315,9 +315,9 @@ class phodevi_linux_parser
 
 		if($try_aticonfig)
 		{
-			if(pts_client::executable_in_path('aticonfig'))
+			if(($amdconfig = self::find_amdconfig()))
 			{
-				$info = shell_exec('aticonfig --get-pcs-key=' . $attribute . ' 2>&1');
+				$info = shell_exec($amdconfig . ' --get-pcs-key=' . $attribute . ' 2>&1');
 
 				if($is_first_read && strpos($info, 'No supported adapters') != false)
 				{
@@ -350,7 +350,7 @@ class phodevi_linux_parser
 	}
 	public static function read_amd_pcsdb_direct_parser($attribute, $find_once = false)
 	{
-		// Read AMD's AMDPCSDB, AMD Persistent Configuration Store Database but using our own internal parser instead of relying upon aticonfig
+		// Read AMD's AMDPCSDB, AMD Persistent Configuration Store Database but using our own internal parser instead of relying upon aticonfig/amdconfig
 		$amdpcsdb_file = null;
 		$last_found_section_count = -1;
 		$this_section_count = 0;
@@ -440,15 +440,29 @@ class phodevi_linux_parser
 
 		return $attribute_values;
 	}
+	public static function find_amdconfig()
+	{
+		$amdconfig = false;
+
+		if(($t = pts_client::executable_in_path('aticonfig')))
+		{
+			$amdconfig = $t;
+		}
+		else if(($t = pts_client::executable_in_path('amdconfig')))
+		{
+			$amdconfig = $t;
+		}
+
+		return $amdconfig;
+	}
 	public static function read_amd_graphics_adapters()
 	{
 		// Read ATI/AMD graphics hardware using aticonfig
-		// TODO XXX: check for amdconfig as well in case AMD drops aticonfig utility name in the future... amdconfig right now is present right now and mirrors aticonfig
 		$adapters = array();
 
-		if(pts_client::executable_in_path('aticonfig'))
+		if(($amdconfig = self::find_amdconfig()))
 		{
-			$info = trim(shell_exec('aticonfig --list-adapters 2>&1'));
+			$info = trim(shell_exec($amdconfig . ' --list-adapters 2>&1'));
 
 			foreach(explode("\n", $info) as $line)
 			{
@@ -544,47 +558,6 @@ class phodevi_linux_parser
 
 		return $info;
 	}
-	public static function read_hal($name, $UDI = null)
-	{
-		// Read HAL - Hardware Abstraction Layer
-		$info = false;
-
-		if(pts_client::executable_in_path('lshal'))
-		{
-			$name = pts_arrays::to_array($name);
-			$remove_words = phodevi_parser::hardware_values_to_remove();
-
-			for($i = 0; $i < count($name) && empty($info); $i++)
-			{
-				$info = shell_exec('lshal ' . (!empty($UDI) ? '-u ' . $UDI : null) . ' 2>&1 | grep "' . $name[$i] . '"');
-
-				if(($pos = strpos($info, $name[$i] . " = '")) !== false)
-				{
-					$info = substr($info, $pos + strlen($name[$i] . " = '"));
-					$info = trim(substr($info, 0, strpos($info, "'")));
-				}
-
-				if(empty($info) || in_array(strtolower($info), $remove_words))
-				{
-					$info = false;
-				}
-			}
-		}
-
-		return $info;
-	}
-	public static function read_system_hal($name)
-	{
-		// Read system HAL
-		$hal = phodevi_linux_parser::read_hal($name, '/org/freedesktop/Hal/devices/computer');
-
-		if($hal == false)
-		{
-			$hal = phodevi_linux_parser::read_hal($name);
-		}
-
-		return $hal;
-	}
 	public static function read_acpi($point, $match)
 	{
 		// Read ACPI - Advanced Configuration and Power Interface
@@ -600,6 +573,12 @@ class phodevi_linux_parser
 				for($i = 0; $i < count($acpi_lines) && $value == false; $i++)
 				{
 					$line = pts_strings::trim_explode(': ', $acpi_lines[$i]);
+
+					if(!isset($line[0]))
+					{
+						continue;
+					}
+
 					$this_attribute = $line[0];
 					$this_value = (count($line) > 1 ? $line[1] : null);
 
@@ -687,9 +666,9 @@ class phodevi_linux_parser
 		// Read LM_Sensors
 		$value = false;
 
-		if(pts_client::executable_in_path('sensors'))
+		if(isset(phodevi::$vfs->sensors))
 		{
-			$sensors = shell_exec('sensors 2>&1');
+			$sensors = phodevi::$vfs->sensors;
 			$sensors_lines = explode("\n", $sensors);
 			$attributes = pts_arrays::to_array($attributes);
 
