@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2009 - 2011, Phoronix Media
-	Copyright (C) 2009 - 2011, Michael Larabel
+	Copyright (C) 2009 - 2012, Phoronix Media
+	Copyright (C) 2009 - 2012, Michael Larabel
 	phodevi.php: The object for interacting with the PTS device framework
 
 	This program is free software; you can redistribute it and/or modify
@@ -21,13 +21,17 @@
 	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
+phodevi::create_vfs();
+
 if(PTS_IS_CLIENT)
 {
 	phodevi::initial_setup();
 }
 
+
 class phodevi
 {
+	public static $vfs = false;
 	private static $device_cache = null;
 	private static $smart_cache = null;
 	private static $sensors = null;
@@ -345,6 +349,10 @@ class phodevi
 
 		return $return_value;
 	}
+	public static function create_vfs()
+	{
+		self::$vfs = new phodevi_vfs();
+	}
 	public static function initial_setup()
 	{
 		// Operating System Detection
