@@ -47,11 +47,8 @@ abstract class pts_Graph
 	protected $graph_identifiers;
 	protected $graph_title;
 	protected $graph_y_title;
-	protected $graph_internal_identifiers = array();
-	protected $regression_marker_threshold = 0;
 	protected $is_multi_way_comparison = false;
 	private $test_identifier = null;
-	protected $link_alternate_view = null;
 	protected $value_highlights = array();
 
 	public function __construct(&$result_object = null, &$result_file = null)
@@ -88,14 +85,12 @@ abstract class pts_Graph
 			$this->test_identifier = $result_object->test_profile->get_identifier();
 			$this->i['graph_proportion'] = $result_object->test_profile->get_result_proportion();
 			$this->addSubTitle($result_object->get_arguments_description());
-			$this->addInternalIdentifier('Test', $result_object->test_profile->get_identifier());
 		}
 
 		$this->update_graph_dimensions(self::$c['graph']['width'], self::$c['graph']['height'], true);
 
 		if($result_file != null && $result_file instanceof pts_result_file)
 		{
-			$this->addInternalIdentifier('Identifier', $result_file->get_identifier());
 			$pts_version = pts_arrays::last_element($result_file->get_system_pts_version());
 			$this->is_multi_way_comparison = $result_file->is_multi_way_comparison();
 		}
@@ -109,14 +104,7 @@ abstract class pts_Graph
 	}
 	public static function init_graph_config($external_config = null)
 	{
-		if(defined('OPENBENCHMARKING_BUILD'))
-		{
-			self::set_openbenchmarking_graph_values(self::$c);
-		}
-		else
-		{
-			self::set_default_graph_values(self::$c);
-		}
+		self::set_default_graph_values(self::$c);
 
 		if($external_config && is_array($external_config))
 		{
@@ -124,39 +112,6 @@ abstract class pts_Graph
 		}
 	}
 	public static function set_default_graph_values(&$config)
-	{
-		// Setup config values
-		$config['graph']['width'] = 580; // Graph width
-		$config['graph']['height'] = 300; // Graph height
-		$config['graph']['border'] = true; // Graph border
-
-		// Colors
-		$config['color']['notches'] = '#454545'; // Color for notches
-		$config['color']['text'] = '#454545'; // Color for text
-		$config['color']['border'] = '#454545'; // Color for border (if used)
-		$config['color']['main_headers'] = '#2B6B29'; // Color of main text headers
-		$config['color']['headers'] = '#2B6B29'; // Color of other headers
-		$config['color']['background'] = '#FEFEFE'; // Color of background
-		$config['color']['body'] = '#BABABA'; // Color of graph body
-		$config['color']['body_text'] = '#FFFFFF'; // Color of graph body text
-		$config['color']['body_light'] = '#949494'; // Color of the border around graph bars (if doing a bar graph)
-		$config['color']['highlight'] = '#005A00'; // Color for highlight
-		$config['color']['alert'] = '#C80000'; // Color for alerts
-		$config['color']['paint'] = array('#2B6B29', '#0b27cf', '#ff9c00', '#d78f1d', '#6B6B6B', '#ff5800', '#221914', '#AC008A', '#E00022', '#3A9137', '#00F6FF', '#8A00AC', '#949200', '#797766', '#5598b1'); // Colors to use for the bars / lines, one color for each key
-
-		// Text
-		$config['size']['tick_mark'] = 10;
-		$config['size']['key'] = 9;
-
-		$config['text']['watermark'] = 'PHORONIX-TEST-SUITE.COM'; // watermark
-		$config['text']['watermark_url'] = 'http://www.phoronix-test-suite.com/'; // watermark URL
-		$config['size']['headers'] = 17; // Font size of headings
-		$config['size']['bars'] = 11; // Font size for text on the bars/objects
-		$config['size']['identifiers'] = 10; // Font size of identifiers
-		$config['size']['sub_headers'] = 11; // Font size of headers
-		$config['size']['axis_headers'] = 10; // Font size of axis headers
-	}
-	public static function set_openbenchmarking_graph_values(&$config)
 	{
 		// Setup config values
 		$config['graph']['width'] = 600;
@@ -181,8 +136,17 @@ abstract class pts_Graph
 		$config['size']['tick_mark'] = 10;
 		$config['size']['key'] = 9;
 
-		$config['text']['watermark'] = 'OpenBenchmarking.org';
-		$config['text']['watermark_url'] = 'http://www.openbenchmarking.org/';
+		if(defined('OPENBENCHMARKING_BUILD'))
+		{
+			$config['text']['watermark'] = 'OpenBenchmarking.org';
+			$config['text']['watermark_url'] = 'http://www.openbenchmarking.org/';
+		}
+		else
+		{
+			$config['text']['watermark'] = 'PHORONIX-TEST-SUITE.COM';
+			$config['text']['watermark_url'] = 'http://www.phoronix-test-suite.com/';
+		}
+
 		$config['size']['headers'] = 17;
 		$config['size']['bars'] = 11;
 		$config['size']['identifiers'] = 10;
@@ -251,17 +215,13 @@ abstract class pts_Graph
 			}
 		}
 	}
-	public function addTestNote($note, $hover_title = null)
+	public function addTestNote($note, $hover_title = null, $section = null)
 	{
-		array_push($this->i['notes'], array('note' => $note, 'hover-title' => $hover_title));
-	}
-	public function addInternalIdentifier($identifier, $value)
-	{
-		$this->graph_internal_identifiers[$identifier] = $value;
+		array_push($this->i['notes'], array('note' => $note, 'hover-title' => $hover_title, 'section' => $section));
 	}
 	public function markResultRegressions($threshold)
 	{
-		$this->regression_marker_threshold = $threshold;
+		$this->d['regression_marker_threshold'] = $threshold;
 	}
 
 	//
@@ -295,7 +255,7 @@ abstract class pts_Graph
 		{
 			if($real_maximum < $this->i['mark_count'])
 			{
-				$maximum = ceil($real_maximum * 1.02 / $this->i['mark_count']) * $this->i['mark_count'];
+				$maximum = ceil(($real_maximum * 1.35 / $this->i['mark_count']) * $this->i['mark_count']);
 			}
 			else
 			{
@@ -469,7 +429,7 @@ abstract class pts_Graph
 	}
 	public function setAlternateView($url)
 	{
-		$this->link_alternate_view = $url;
+		$this->d['link_alternate_view'] = $url;
 	}
 	public function render_graph_finish()
 	{
@@ -537,28 +497,28 @@ abstract class pts_Graph
 				}
 			}
 
-			$this->svg_dom->add_text_element($this->graph_title, array('x' => 5, 'y' => 12, 'font-size' => self::$c['size']['headers'], 'fill' => self::$c['color']['background'], 'text-anchor' => 'start', 'dominant-baseline' => 'middle', 'xlink:show' => 'new', 'xlink:href' => $href));
+			$this->svg_dom->add_text_element($this->graph_title, array('x' => 6, 'y' => (self::$c['size']['headers'] + 2), 'font-size' => self::$c['size']['headers'], 'fill' => self::$c['color']['background'], 'text-anchor' => 'start', 'xlink:show' => 'new', 'xlink:href' => $href));
 
 			foreach($this->graph_sub_titles as $i => $sub_title)
 			{
-				$vertical_offset = 12 + 4 + self::$c['size']['headers'] + ($i * (self::$c['size']['sub_headers'] + 5));
-				$this->svg_dom->add_text_element($sub_title, array('x' => 5, 'y' => $vertical_offset, 'font-size' => self::$c['size']['sub_headers'], 'fill' => self::$c['color']['background'], 'text-anchor' => 'start', 'dominant-baseline' => 'middle'));
+				$vertical_offset = 12 + self::$c['size']['headers'] + (($i + 1) * (self::$c['size']['sub_headers'] - 4));
+				$this->svg_dom->add_text_element($sub_title, array('x' => 6, 'y' => $vertical_offset, 'font-size' => self::$c['size']['sub_headers'], 'fill' => self::$c['color']['background'], 'text-anchor' => 'start'));
 			}
 
 			$this->svg_dom->add_element('image', array('http_link' => 'http://www.phoronix-test-suite.com/', 'xlink:href' => pts_svg_dom::embed_png_image(PTS_CORE_STATIC_PATH . 'images/pts-77x40-white.png'), 'x' => ($this->i['graph_left_end'] - 77), 'y' => (($this->i['top_heading_height'] / 40 + 2)), 'width' => 77, 'height' => 40));
 		}
 		else
 		{
-			$this->svg_dom->add_text_element($this->graph_title, array('x' => round($this->i['graph_left_end'] / 2), 'y' => 3, 'font-size' => self::$c['size']['headers'], 'fill' => self::$c['color']['main_headers'], 'text-anchor' => 'middle', 'dominant-baseline' => 'text-before-edge', 'xlink:show' => 'new', 'xlink:href' => $href));
+			$this->svg_dom->add_text_element($this->graph_title, array('x' => round($this->i['graph_left_end'] / 2), 'y' => (self::$c['size']['headers'] + 2), 'font-size' => self::$c['size']['headers'], 'fill' => self::$c['color']['main_headers'], 'text-anchor' => 'middle', 'xlink:show' => 'new', 'xlink:href' => $href));
 
 			foreach($this->graph_sub_titles as $i => $sub_title)
 			{
-				$this->svg_dom->add_text_element($sub_title, array('x' => round($this->i['graph_left_end'] / 2), 'y' => (31 + ($i * 18)), 'font-size' => self::$c['size']['sub_headers'], 'fill' => self::$c['color']['main_headers'], 'text-anchor' => 'middle', 'dominant-baseline' => 'text-before-edge'));
+				$this->svg_dom->add_text_element($sub_title, array('x' => round($this->i['graph_left_end'] / 2), 'y' => (31 + (($i + 1) * 18)), 'font-size' => self::$c['size']['sub_headers'], 'fill' => self::$c['color']['main_headers'], 'text-anchor' => 'middle'));
 			}
 
 			if($with_version)
 			{
-				$this->svg_dom->add_text_element($this->i['graph_version'], array('x' => $this->i['graph_left_end'] , 'y' => ($this->i['top_start'] - 3), 'font-size' => 7, 'fill' => self::$c['color']['body_light'], 'text-anchor' => 'end', 'dominant-baseline' => 'bottom', 'xlink:show' => 'new', 'xlink:href' => 'http://www.phoronix-test-suite.com/'));
+				$this->svg_dom->add_text_element($this->i['graph_version'], array('x' => $this->i['graph_left_end'] , 'y' => ($this->i['top_start'] - 3), 'font-size' => 7, 'fill' => self::$c['color']['body_light'], 'text-anchor' => 'end', 'xlink:show' => 'new', 'xlink:href' => 'http://www.phoronix-test-suite.com/'));
 			}
 		}
 	}
@@ -568,12 +528,12 @@ abstract class pts_Graph
 		{
 			$bottom_heading_start = $this->i['graph_top_end'] + $this->i['bottom_offset'] + 22;
 			$this->svg_dom->add_element('rect', array('x' => 0, 'y' => $bottom_heading_start, 'width' => $this->i['graph_width'], 'height' => ($this->i['graph_height'] - $bottom_heading_start), 'fill' => self::$c['color']['main_headers']));
-			$this->svg_dom->add_text_element('Powered By ' . $this->i['graph_version'], array('x' => $this->i['graph_left_end'], 'y' => ($bottom_heading_start + 9), 'font-size' => (self::$c['size']['key'] - 1), 'fill' => self::$c['color']['background'], 'text-anchor' => 'end', 'dominant-baseline' => 'middle', 'xlink:show' => 'new', 'xlink:href' => 'http://www.phoronix-test-suite.com/'));
+			$this->svg_dom->add_text_element('Powered By ' . $this->i['graph_version'], array('x' => $this->i['graph_left_end'], 'y' => ($bottom_heading_start + self::$c['size']['key'] + 3), 'font-size' => self::$c['size']['key'], 'fill' => self::$c['color']['background'], 'text-anchor' => 'end', 'xlink:show' => 'new', 'xlink:href' => 'http://www.phoronix-test-suite.com/'));
 
-			if($this->link_alternate_view)
+			if(isset($this->d['link_alternate_view']) && $this->d['link_alternate_view'])
 			{
-				// offer link of image to $this->link_alternate_view
-				$this->svg_dom->add_element('image', array('http_link' => $this->link_alternate_view, 'xlink:href' => pts_svg_dom::embed_png_image(PTS_CORE_STATIC_PATH . 'images/ob-10x16.png'), 'x' => 4, 'y' => ($bottom_heading_start + 1), 'width' => 10, 'height' => 16));
+				// offer link of image to $this->d['link_alternate_view']
+				$this->svg_dom->add_element('image', array('http_link' => $this->d['link_alternate_view'], 'xlink:href' => pts_svg_dom::embed_png_image(PTS_CORE_STATIC_PATH . 'images/ob-10x16.png'), 'x' => 4, 'y' => ($bottom_heading_start + 1), 'width' => 10, 'height' => 16));
 			}
 
 			if(!empty($this->i['notes']))
@@ -581,7 +541,7 @@ abstract class pts_Graph
 				$estimated_height = 0;
 				foreach($this->i['notes'] as $i => $note_r)
 				{
-					$this->svg_dom->add_textarea_element(($i + 1) . '. ' . $note_r['note'], array('x' => 5, 'y' => ($bottom_heading_start + (self::$c['size']['key'] * 2) + 4 + $estimated_height), 'font-size' => (self::$c['size']['key'] - 1), 'fill' => self::$c['color']['background'], 'text-anchor' => 'start', 'dominant-baseline' => 'middle', 'xlink:title' => $note_r['hover-title']), $estimated_height);
+					$this->svg_dom->add_textarea_element(($i + 1) . '. ' . $note_r['note'], array('x' => 5, 'y' => ($bottom_heading_start + (self::$c['size']['key'] * 2) + 8 + $estimated_height), 'font-size' => (self::$c['size']['key'] - 1), 'fill' => self::$c['color']['background'], 'text-anchor' => 'start', 'xlink:title' => $note_r['hover-title']), $estimated_height);
 				}
 			}
 		}
@@ -595,7 +555,7 @@ abstract class pts_Graph
 
 			if(!empty(self::$c['text']['watermark']))
 			{
-				$this->svg_dom->add_text_element(self::$c['text']['watermark'], array('x' => $left_end, 'y' => ($top_start - 7), 'font-size' => 7, 'fill' => self::$c['color']['text'], 'text-anchor' => 'end', 'dominant-baseline' => 'middle', 'xlink:show' => 'new', 'xlink:href' => self::$c['text']['watermark_url']));
+				$this->svg_dom->add_text_element(self::$c['text']['watermark'], array('x' => $left_end, 'y' => ($top_start - 5), 'font-size' => 7, 'fill' => self::$c['color']['text'], 'text-anchor' => 'end', 'xlink:show' => 'new', 'xlink:href' => self::$c['text']['watermark_url']));
 			}
 		}
 		else
@@ -604,7 +564,7 @@ abstract class pts_Graph
 
 			if(self::$c['text']['watermark'] != null)
 			{
-				$this->svg_dom->add_text_element(self::$c['text']['watermark'], array('x' => ($left_end - 2), 'y' => ($top_start + 8), 'font-size' => 10, 'fill' => self::$c['color']['text'], 'text-anchor' => 'end', 'dominant-baseline' => 'middle', 'xlink:show' => 'new', 'xlink:href' => self::$c['text']['watermark_url']));
+				$this->svg_dom->add_text_element(self::$c['text']['watermark'], array('x' => ($left_end - 2), 'y' => ($top_start + 12), 'font-size' => 10, 'fill' => self::$c['color']['text'], 'text-anchor' => 'end', 'xlink:show' => 'new', 'xlink:href' => self::$c['text']['watermark_url']));
 			}
 		}
 
@@ -656,7 +616,7 @@ abstract class pts_Graph
 				}
 			}
 
-			$this->svg_dom->add_text_element($str, array('x' => ($left_start + $offset), 'y' => ($top_start - 7), 'font-size' => 7, 'fill' => self::$c['color']['text'], 'text-anchor' => 'start', 'dominant-baseline' => 'middle'));
+			$this->svg_dom->add_text_element($str, array('x' => ($left_start + $offset), 'y' => ($top_start - 5), 'font-size' => 7, 'fill' => self::$c['color']['text'], 'text-anchor' => 'start'));
 		}
 	}
 	protected function render_graph_value_ticks($left_start, $top_start, $left_end, $top_end)
@@ -674,7 +634,7 @@ abstract class pts_Graph
 
 				if($i != 0)
 				{
-					$this->svg_dom->add_text_element($display_value, array('x' => $px_from_left, 'y' => ($top_end + 5), 'font-size' => self::$c['size']['tick_mark'], 'fill' => self::$c['color']['text'], 'text-anchor' => 'middle', 'dominant-baseline' => 'text-before-edge'));
+					$this->svg_dom->add_text_element($display_value, array('x' => $px_from_left, 'y' => ($top_end + 5 + self::$c['size']['tick_mark']), 'font-size' => self::$c['size']['tick_mark'], 'fill' => self::$c['color']['text'], 'text-anchor' => 'middle'));
 					$this->svg_dom->draw_svg_line($px_from_left + 2, $top_start, $px_from_left + 2, $top_end - 5, self::$c['color']['body'], 1, array('stroke-dasharray' => '5,5'));
 					$this->svg_dom->draw_svg_line($px_from_left + 2, $top_end - 4, $px_from_left + 2, $top_end + 4, self::$c['color']['notches'], 1);
 				}
@@ -697,7 +657,7 @@ abstract class pts_Graph
 
 				if($i != 0)
 				{
-					$this->svg_dom->add_text_element($display_value, array('x' => ($px_from_left_start - 4), 'y' => $px_from_top, 'font-size' => self::$c['size']['tick_mark'], 'fill' =>  self::$c['color']['text'], 'text-anchor' => 'end', 'dominant-baseline' => 'middle'));
+					$this->svg_dom->add_text_element($display_value, array('x' => ($px_from_left_start - 4), 'y' => round($px_from_top + (self::$c['size']['tick_mark'] / 2)), 'font-size' => self::$c['size']['tick_mark'], 'fill' =>  self::$c['color']['text'], 'text-anchor' => 'end'));
 
 					if($this->i['show_background_lines'])
 					{
@@ -756,7 +716,7 @@ abstract class pts_Graph
 				$x = $this->i['left_start'] + 13 + ($this->i['key_item_width'] * ($i % $this->i['keys_per_line']));
 
 				$this->svg_dom->add_element('rect', array('x' => ($x - 13), 'y' => ($y - 5), 'width' => 10, 'height' => 10, 'fill' => $this_color, 'stroke' => self::$c['color']['notches'], 'stroke-width' => 1));
-				$this->svg_dom->add_text_element($this->graph_data_title[$i], array('x' => $x, 'y' => $y, 'font-size' => self::$c['size']['key'], 'fill' => $this_color, 'text-anchor' => 'start', 'dominant-baseline' => 'middle'));
+				$this->svg_dom->add_text_element($this->graph_data_title[$i], array('x' => $x, 'y' => ($y + 4), 'font-size' => self::$c['size']['key'], 'fill' => $this_color, 'text-anchor' => 'start'));
 			}
 		}
 	}
@@ -862,14 +822,22 @@ abstract class pts_Graph
 		// This basically figures out how many lines of notes there are times the size of the font key...
 		// additionally, it attempts to figure out if the note will word-wrap to additional lines to accomodate that
 		$note_height = 0;
+		$sections = array();
 		if(!empty($this->i['notes']))
 		{
 			foreach($this->i['notes'] as $note)
 			{
 				// If the note isn't at least 36 characters long, assume it's not long enough to word-wrap, so take short-cut for efficiency
-				$note_height += !isset($note['note'][36]) ? (self::$c['size']['key'] + 2) : (ceil($this->text_string_width($note['note'], self::$c['size']['key']) / ($this->i['graph_width'] - 14)) + 1) * self::$c['size']['key'];
+				$note_height += !isset($note['note'][36]) ? (self::$c['size']['key'] + 2) : (ceil($this->text_string_width($note['note'], self::$c['size']['key']) / ($this->i['graph_width'] - 14))) * self::$c['size']['key'];
+
+				if($note['section'] != null)
+				{
+					array_push($sections, $note['section']);
+				}
 			}
+			$note_height += self::$c['size']['key'];
 		}
+		$note_height += ((count(array_unique($sections)) + 1) * (self::$c['size']['key'] + 6));
 
 		return $note_height;
 	}
