@@ -84,7 +84,7 @@ class pts_render
 			return;
 		}
 
-		if(!isset($extra_attributes['compact_to_scalar']) && $result_object->test_profile->get_display_format() == 'LINE_GRAPH' && $result_file->get_system_count() > 8)
+		if(!isset($extra_attributes['compact_to_scalar']) && $result_object->test_profile->get_display_format() == 'LINE_GRAPH' && $result_file->get_system_count() > 10)
 		{
 			// If there's too many lines being plotted on line graph, likely to look messy, so convert to scalar automatically
 			$extra_attributes['compact_to_scalar'] = true;
@@ -376,54 +376,68 @@ class pts_render
 	{
 		$system_json = $result_file->get_system_json();
 		$identifiers = $result_file->get_system_identifiers();
-		$compiler_configuration = array();
-		$disk_options = array();
+		$identifier_count = count($identifiers);
+		$system_attributes = array();
 
 		foreach($system_json as $i => $json)
 		{
 			if(isset($json['compiler-configuration']) && $json['compiler-configuration'] != null)
 			{
-				$compiler_configuration[$identifiers[$i]] = $json['compiler-configuration'];
+				$system_attributes['Compiler'][$identifiers[$i]] = $json['compiler-configuration'];
 			}
 			if(isset($json['disk-scheduler']) && isset($json['disk-mount-options']))
 			{
-				$disk_options[$identifiers[$i]] = $json['disk-scheduler'] . ' / ' . $json['disk-mount-options'];
+				$system_attributes['Disk'][$identifiers[$i]] = $json['disk-scheduler'] . ' / ' . $json['disk-mount-options'];
+			}
+			if(isset($json['cpu-scaling-governor']))
+			{
+				$system_attributes['Processor'][$identifiers[$i]] = 'Scaling Governor: ' . $json['cpu-scaling-governor'];
+			}
+			if(isset($json['graphics-2d-acceleration']))
+			{
+				$system_attributes['Graphics'][$identifiers[$i]] = '2D Acceleration: ' . $json['graphics-2d-acceleration'];
+			}
+			if(isset($json['graphics-compute-cores']))
+			{
+				$system_attributes['OpenCL'][$identifiers[$i]] = 'GPU Compute Cores: ' . $json['graphics-compute-cores'];
 			}
 		}
 
-		switch(count(array_unique($compiler_configuration)))
+		if(isset($system_attributes['compiler']) && count($system_attributes['compiler']) == 1 && ($result_file->get_system_count() > 1 && ($intent = pts_result_file_analyzer::analyze_result_file_intent($result_file, $intent, true)) && isset($intent[0]) && is_array($intent[0]) && array_shift($intent[0]) == 'Compiler') == false)
 		{
-			case 0:
-				break;
-			case 1:
-				$intent = -1;
-				if($result_file->get_system_count() > 1 && ($intent = pts_result_file_analyzer::analyze_result_file_intent($result_file, $intent, true)) && isset($intent[0]) && is_array($intent[0]) && array_shift($intent[0]) == 'Compiler')
-				{
-					// Even if the compiler build configuration isn't changing but a compiler is being compared, might as well report its build configuration
-					$table->addTestNote('CC: ' . array_pop($compiler_configuration));
-				}
-				break;
-			default:
-				foreach($compiler_configuration as $identifier => $configuration)
-				{
-					$table->addTestNote($identifier . ' CC: ' . $configuration);
-				}
-				break;
+			// Only show compiler strings when it's meaningful (since they tend to be long strings)
+			unset($system_attributes['compiler']);
 		}
 
-		switch(count(array_unique($disk_options)))
+		foreach($system_attributes as $index_name => $attributes)
 		{
-			case 0:
-				break;
-			case 1:
-				$table->addTestNote(array_pop($disk_options));
-				break;
-			default:
-				foreach($disk_options as $identifier => $configuration)
-				{
-					$table->addTestNote($identifier . ': ' . $configuration);
-				}
-				break;
+			$unique_attribue_count = count(array_unique($attributes));
+
+			$section = $identifier_count > 1 ? ucwords($index_name) : null;
+
+			switch($unique_attribue_count)
+			{
+				case 0:
+					break;
+				case 1:
+					if($identifier_count == count($attributes))
+					{
+						// So there is something for all of the test runs and it's all the same...
+						$table->addTestNote(array_pop($attributes), null, $section);
+					}
+					else
+					{
+						// There is missing data for some test runs for this value so report the runs this is relevant to.
+						$table->addTestNote(implode(', ', array_keys($attributes)) . ': ' . array_pop($attributes), null, $section);
+					}
+					break;
+				default:
+					foreach($attributes as $identifier => $configuration)
+					{
+						$table->addTestNote($identifier . ': ' . $configuration, null, $section);
+					}
+					break;
+			}
 		}
 	}
 	protected static function report_test_notes_to_graph(&$graph, &$result_object)
@@ -548,7 +562,7 @@ class pts_render
 
 			foreach($common_segments as $pos => $word)
 			{
-				if(!isset($this_identifier[$pos]) || $this_identifier[$pos] != $word || !isset($word[2]))
+				if(!isset($this_identifier[$pos]) || $this_identifier[$pos] != $word || !isset($word[2]) || !ctype_alnum(substr($word, -1)))
 				{
 					// The word isn't the same OR the string is less than three characters (e.g. i7 or HD don't chop off from product names
 					unset($common_segments[$pos]);
@@ -717,7 +731,7 @@ class pts_render
 						$sha1_short_count++;
 					}
 
-					if($prev_date != null && $date != $prev_date && $sha1_short_hash_ending == false && $sha1_short_count < 2)
+					if($prev_date != null && $date != $prev_date && $sha1_short_hash_ending == false && $sha1_short_count < 3)
 					{
 						$is_tracking = false;
 					}
@@ -727,7 +741,17 @@ class pts_render
 			}
 		}
 
-		if($is_tracking == false && $sha1_short_count > 5)
+		if($is_tracking)
+		{
+			$prev_date_r = explode(' ', $prev_date);
+
+			if(count($prev_date_r) == 2 && ctype_alpha($prev_date_r[0]))
+			{
+				// This check should make it so when like testing every Ubuntu releases (Ubuntu 11.04, Ubuntu 11.10, etc) it's not in a line graph
+				$is_tracking = false;
+			}
+		}
+		else if($is_tracking == false && $sha1_short_count > 5)
 		{
 			// It's probably actually tracking..... based upon Stefan's Wine 1.4 example on 15 March 2012
 			$is_tracking = true;
@@ -739,6 +763,7 @@ class pts_render
 		}
 
 		$raw_days = $days;
+		$json_days = $days;
 
 		foreach($mto->test_result_buffer->get_buffer_items() as $buffer_item)
 		{
@@ -761,6 +786,7 @@ class pts_render
 
 			$days[$date][$system] = $buffer_item->get_result_value();
 			$raw_days[$date][$system] = $buffer_item->get_result_raw();
+			$json_days[$date][$system] = $buffer_item->get_result_json();
 
 			if(!is_numeric($days[$date][$system]))
 			{
@@ -815,14 +841,27 @@ class pts_render
 			{
 				$results = array();
 				$raw_results = array();
+				$json_results = array();
 
 				foreach($day_keys as $day_key)
 				{
 					array_push($results, $days[$day_key][$system_key]);
 					array_push($raw_results, $raw_days[$day_key][$system_key]);
+					pts_arrays::unique_push($json_results, $json_days[$day_key][$system_key]);
 				}
 
-				$mto->test_result_buffer->add_test_result($system_key, implode(',', $results), implode(',', $raw_results));
+				// TODO XXX: Make JSON data work for multi-way comparisons!
+
+				if(count($json_results) == 1)
+				{
+					$json = array_shift($json_results);
+				}
+				else
+				{
+					$json = null;
+				}
+
+				$mto->test_result_buffer->add_test_result($system_key, implode(',', $results), implode(',', $raw_results), $json);
 			}
 		}
 
@@ -1008,7 +1047,8 @@ class pts_render
 			}
 
 			// text-alignment is still fucked as of 11.50/12.0
-			$selected_renderer = 'PNG';
+			// With PTS4 and the bilde_svg_dom calls not using dominant-baseline, Opera support seems to be fine
+			// $selected_renderer = 'PNG';
 		}
 		else if(($p = strpos($user_agent, 'Epiphany/')) !== false)
 		{
